@@ -156,8 +156,12 @@ class CortxJupyter(ContentsManager):
             "endpoint_url":self.endpoint_url
         }
 
-        with open('.credentials',"w") as fp:
-            json.dumps(creds,fp)
+        with open('credentials.json',"w") as fp:
+            json.dump(creds,fp)
+
+        print(json.load(open("credentials.json","r").read()))
+        # with open('credentials.json',"r") as fp):
+        #     print(json.load(fp))
 
         return Config(
             region=self.region_name,
